@@ -1,29 +1,28 @@
 /***
-* Copyright (C) Microsoft. All rights reserved.
-* Licensed under the MIT license. See LICENSE.txt file in the project root for full license information.
-*
-* =+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+
-*
-* HTTP Library: Client-side APIs.
-*
-* This file contains the implementation for the Windows Runtime, using XML HTTP Extended Request.
-*
-* For the latest on this and related APIs, please see: https://github.com/Microsoft/cpprestsdk
-*
-* =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
-****/
+ * Copyright (C) Microsoft. All rights reserved.
+ * Licensed under the MIT license. See LICENSE.txt file in the project root for full license information.
+ *
+ * =+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+
+ *
+ * HTTP Library: Client-side APIs.
+ *
+ * This file contains the implementation for the Windows Runtime, using XML HTTP Extended Request.
+ *
+ * For the latest on this and related APIs, please see: https://github.com/Microsoft/cpprestsdk
+ *
+ * =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
+ ****/
 #include "stdafx.h"
 
-#include "http_client_impl.h"
 #include "../common/internal_http_helpers.h"
-
+#include "http_client_impl.h"
 #include <Strsafe.h>
 // Important for WP8
 #if !defined(__WRL_NO_DEFAULT_LIB__)
 #define __WRL_NO_DEFAULT_LIB__
 #endif
-#include <wrl.h>
 #include <msxml6.h>
+#include <wrl.h>
 using namespace std;
 using namespace Platform;
 using namespace Microsoft::WRL;
@@ -36,14 +35,13 @@ namespace client
 {
 namespace details
 {
-
 // Additional information necessary to track a WinRT request.
 class winrt_request_context final : public request_context
 {
 public:
-
     // Factory function to create requests on the heap.
-    static std::shared_ptr<request_context> create_request_context(const std::shared_ptr<_http_client_communicator> &client, http_request &request)
+    static std::shared_ptr<request_context> create_request_context(
+        const std::shared_ptr<_http_client_communicator>& client, http_request& request)
     {
         return std::make_shared<winrt_request_context>(client, request);
     }
@@ -53,35 +51,31 @@ public:
 
     // Request contexts must be created through factory function.
     // But constructor needs to be public for make_shared to access.
-    winrt_request_context(const std::shared_ptr<_http_client_communicator> &client, http_request &request)
+    winrt_request_context(const std::shared_ptr<_http_client_communicator>& client, http_request& request)
         : request_context(client, request), m_hRequest(nullptr), m_exceptionPtr()
     {
     }
 };
 
 // Implementation of IXMLHTTPRequest2Callback.
-class HttpRequestCallback final :
-    public RuntimeClass<RuntimeClassFlags<ClassicCom>, IXMLHTTPRequest2Callback, FtmBase>
+class HttpRequestCallback final : public RuntimeClass<RuntimeClassFlags<ClassicCom>, IXMLHTTPRequest2Callback, FtmBase>
 {
 public:
-    HttpRequestCallback(const std::shared_ptr<winrt_request_context> &request)
-        : m_request(request)
-    {
-    }
+    HttpRequestCallback(const std::shared_ptr<winrt_request_context>& request) : m_request(request) {}
 
     // Called when the HTTP request is being redirected to a new URL.
-    HRESULT STDMETHODCALLTYPE OnRedirect(_In_opt_ IXMLHTTPRequest2*, __RPC__in_string const WCHAR*) {
-        return S_OK;
-    }
+    HRESULT STDMETHODCALLTYPE OnRedirect(_In_opt_ IXMLHTTPRequest2*, __RPC__in_string const WCHAR*) { return S_OK; }
 
     // Called when HTTP headers have been received and processed.
-    HRESULT STDMETHODCALLTYPE OnHeadersAvailable(_In_ IXMLHTTPRequest2* xmlReq, DWORD dw, __RPC__in_string const WCHAR* phrase)
+    HRESULT STDMETHODCALLTYPE OnHeadersAvailable(_In_ IXMLHTTPRequest2* xmlReq,
+                                                 DWORD dw,
+                                                 __RPC__in_string const WCHAR* phrase)
     {
-        http_response &response = m_request->m_response;
+        http_response& response = m_request->m_response;
         response.set_status_code((http::status_code)dw);
         response.set_reason_phrase(phrase);
 
-        utf16char *hdrStr = nullptr;
+        utf16char* hdrStr = nullptr;
         HRESULT hr = xmlReq->GetAllResponseHeaders(&hdrStr);
         if (SUCCEEDED(hr))
         {
@@ -113,17 +107,19 @@ public:
     }
 
     // Called when a portion of the entity body has been received.
-    HRESULT STDMETHODCALLTYPE OnDataAvailable(_In_opt_ IXMLHTTPRequest2*, _In_opt_ ISequentialStream* ) {
-        return S_OK;
-    }
+    HRESULT STDMETHODCALLTYPE OnDataAvailable(_In_opt_ IXMLHTTPRequest2*, _In_opt_ ISequentialStream*) { return S_OK; }
 
     // Called when the entire entity response has been received.
-    HRESULT STDMETHODCALLTYPE OnResponseReceived(_In_opt_ IXMLHTTPRequest2*, _In_opt_ ISequentialStream* )
+    HRESULT STDMETHODCALLTYPE OnResponseReceived(_In_opt_ IXMLHTTPRequest2*, _In_opt_ ISequentialStream*)
     {
         auto progress = m_request->m_request._get_impl()->_progress_handler();
-        if ( progress && m_request->m_downloaded == 0)
+        if (progress && m_request->m_downloaded == 0)
         {
-            try { (*progress)(message_direction::download, 0); } catch(...)
+            try
+            {
+                (*progress)(message_direction::download, 0);
+            }
+            catch (...)
             {
                 m_request->m_exceptionPtr = std::current_exception();
             }
@@ -160,8 +156,7 @@ public:
             std::wstring msg(L"IXMLHttpRequest2Callback::OnError: ");
             msg.append(std::to_wstring(hrError));
             msg.append(L": ");
-            msg.append(utility::conversions::to_string_t(
-                utility::details::windows_category().message(hrError)));
+            msg.append(utility::conversions::to_string_t(utility::details::windows_category().message(hrError)));
             m_request->report_error(hrError, msg);
         }
         else
@@ -192,9 +187,9 @@ class IRequestStream final
     : public Microsoft::WRL::RuntimeClass<Microsoft::WRL::RuntimeClassFlags<ClassicCom>, ISequentialStream>
 {
 public:
-    IRequestStream(const std::weak_ptr<winrt_request_context> &context, size_t read_length = std::numeric_limits<size_t>::max())
-        : m_context(context),
-        m_read_length(read_length)
+    IRequestStream(const std::weak_ptr<winrt_request_context>& context,
+                   size_t read_length = std::numeric_limits<size_t>::max())
+        : m_context(context), m_read_length(read_length)
     {
         // read_length is the initial length of the ISequentialStream that is available for read
         // This is required because IXHR2 attempts to read more data that what is specified by
@@ -202,10 +197,10 @@ public:
         // the content_length specified).
     }
 
-    virtual HRESULT STDMETHODCALLTYPE Read(_Out_writes_ (cb) void *pv, _In_ ULONG cb, _Out_ ULONG *pcbRead)
+    virtual HRESULT STDMETHODCALLTYPE Read(_Out_writes_(cb) void* pv, _In_ ULONG cb, _Out_ ULONG* pcbRead)
     {
         auto context = m_context.lock();
-        if(context == nullptr)
+        if (context == nullptr)
         {
             // OnError has already been called so just error out
             return STG_E_READFAULT;
@@ -219,7 +214,7 @@ public:
             msl::safeint3::SafeInt<size_t> safe_count = static_cast<size_t>(cb);
             size_t size_to_read = safe_count.Min(m_read_length);
 
-            const size_t count = buffer.getn((uint8_t *)pv, size_to_read).get();
+            const size_t count = buffer.getn((uint8_t*)pv, size_to_read).get();
             *pcbRead = (ULONG)count;
             if (count == 0 && size_to_read != 0)
             {
@@ -231,10 +226,14 @@ public:
             m_read_length -= count;
 
             auto progress = context->m_request._get_impl()->_progress_handler();
-            if ( progress && count > 0 )
+            if (progress && count > 0)
             {
                 context->m_uploaded += count;
-                try { (*progress)(message_direction::upload, context->m_uploaded); } catch(...)
+                try
+                {
+                    (*progress)(message_direction::upload, context->m_uploaded);
+                }
+                catch (...)
                 {
                     context->m_exceptionPtr = std::current_exception();
                     return STG_E_READFAULT;
@@ -243,14 +242,16 @@ public:
 
             return S_OK;
         }
-        catch(...)
+        catch (...)
         {
             context->m_exceptionPtr = std::current_exception();
             return STG_E_READFAULT;
         }
     }
 
-    virtual HRESULT STDMETHODCALLTYPE Write(_In_reads_bytes_(cb) const void *pv, _In_ ULONG cb, _Out_opt_ ULONG *pcbWritten)
+    virtual HRESULT STDMETHODCALLTYPE Write(_In_reads_bytes_(cb) const void* pv,
+                                            _In_ ULONG cb,
+                                            _Out_opt_ ULONG* pcbWritten)
     {
         CASABLANCA_UNREFERENCED_PARAMETER(pv);
         CASABLANCA_UNREFERENCED_PARAMETER(cb);
@@ -259,7 +260,6 @@ public:
     }
 
 private:
-
     // The request context controls the lifetime of this class so we only hold a weak_ptr.
     std::weak_ptr<winrt_request_context> m_context;
 
@@ -281,14 +281,14 @@ class IResponseStream final
     : public Microsoft::WRL::RuntimeClass<Microsoft::WRL::RuntimeClassFlags<ClassicCom>, ISequentialStream>
 {
 public:
-    IResponseStream(const std::weak_ptr<winrt_request_context> &context)
-        : m_context(context)
-    { }
+    IResponseStream(const std::weak_ptr<winrt_request_context>& context) : m_context(context) {}
 
-    virtual HRESULT STDMETHODCALLTYPE Write(_In_reads_bytes_(cb) const void *pv, _In_ ULONG cb, _Out_opt_ ULONG *pcbWritten)
+    virtual HRESULT STDMETHODCALLTYPE Write(_In_reads_bytes_(cb) const void* pv,
+                                            _In_ ULONG cb,
+                                            _Out_opt_ ULONG* pcbWritten)
     {
         auto context = m_context.lock();
-        if(context == nullptr)
+        if (context == nullptr)
         {
             // OnError has already been called so just error out
             return STG_E_CANTSAVE;
@@ -307,20 +307,25 @@ public:
         try
         {
             auto buffer = context->_get_writebuffer();
-            const size_t count = buffer.putn_nocopy(reinterpret_cast<const uint8_t *>(pv), static_cast<size_t>(cb)).get();
+            const size_t count =
+                buffer.putn_nocopy(reinterpret_cast<const uint8_t*>(pv), static_cast<size_t>(cb)).get();
 
             _ASSERTE(count != static_cast<size_t>(-1));
             _ASSERTE(count <= static_cast<size_t>(ULONG_MAX));
             if (pcbWritten != nullptr)
             {
-                *pcbWritten = (ULONG) count;
+                *pcbWritten = (ULONG)count;
             }
             context->m_downloaded += count;
 
             auto progress = context->m_request._get_impl()->_progress_handler();
             if (progress && count > 0)
             {
-                try { (*progress)(message_direction::download, context->m_downloaded); } catch(...)
+                try
+                {
+                    (*progress)(message_direction::download, context->m_downloaded);
+                }
+                catch (...)
                 {
                     context->m_exceptionPtr = std::current_exception();
                     return STG_E_CANTSAVE;
@@ -329,14 +334,16 @@ public:
 
             return S_OK;
         }
-        catch(...)
+        catch (...)
         {
             context->m_exceptionPtr = std::current_exception();
             return STG_E_CANTSAVE;
         }
     }
 
-    virtual HRESULT STDMETHODCALLTYPE Read(_Out_writes_bytes_to_(cb, *pcbRead) void *pv, _In_ ULONG cb, _Out_ ULONG *pcbRead)
+    virtual HRESULT STDMETHODCALLTYPE Read(_Out_writes_bytes_to_(cb, *pcbRead) void* pv,
+                                           _In_ ULONG cb,
+                                           _Out_ ULONG* pcbRead)
     {
         CASABLANCA_UNREFERENCED_PARAMETER(pv);
         CASABLANCA_UNREFERENCED_PARAMETER(cb);
@@ -345,7 +352,6 @@ public:
     }
 
 private:
-
     // The request context controls the lifetime of this class so we only hold a weak_ptr.
     std::weak_ptr<winrt_request_context> m_context;
 };
@@ -355,10 +361,12 @@ class winrt_client final : public _http_client_communicator
 {
 public:
     winrt_client(http::uri&& address, http_client_config&& client_config)
-        : _http_client_communicator(std::move(address), std::move(client_config)) { }
+        : _http_client_communicator(std::move(address), std::move(client_config))
+    {
+    }
 
     winrt_client(const winrt_client&) = delete;
-    winrt_client &operator=(const winrt_client&) = delete;
+    winrt_client& operator=(const winrt_client&) = delete;
 
     virtual pplx::task<http_response> propagate(http_request request) override
     {
@@ -375,11 +383,10 @@ public:
     }
 
 protected:
-
     // Start sending request.
-    virtual void send_request(_In_ const std::shared_ptr<request_context> &request) override
+    virtual void send_request(_In_ const std::shared_ptr<request_context>& request) override
     {
-        http_request &msg = request->m_request;
+        http_request& msg = request->m_request;
         auto winrt_context = std::static_pointer_cast<winrt_request_context>(request);
 
         if (!web::http::details::validate_method(msg.method()))
@@ -404,12 +411,11 @@ protected:
         }
 
         // Start sending HTTP request.
-        HRESULT hr = CoCreateInstance(
-            __uuidof(FreeThreadedXMLHTTP60),
-            nullptr,
-            CLSCTX_INPROC,
-            __uuidof(IXMLHTTPRequest2),
-            reinterpret_cast<void**>(winrt_context->m_hRequest.GetAddressOf()));
+        HRESULT hr = CoCreateInstance(__uuidof(FreeThreadedXMLHTTP60),
+                                      nullptr,
+                                      CLSCTX_INPROC,
+                                      __uuidof(IXMLHTTPRequest2),
+                                      reinterpret_cast<void**>(winrt_context->m_hRequest.GetAddressOf()));
         if (FAILED(hr))
         {
             request->report_error(hr, L"Failure to create IXMLHTTPRequest2 instance");
@@ -418,10 +424,10 @@ protected:
 
         utility::string_t encoded_resource = http::uri_builder(m_uri).append(msg.relative_uri()).to_string();
 
-        const auto &config = client_config();
-        const auto &client_cred = config.credentials();
-        const auto &proxy = config.proxy();
-        const auto &proxy_cred = proxy.credentials();
+        const auto& config = client_config();
+        const auto& client_cred = config.credentials();
+        const auto& proxy = config.proxy();
+        const auto& proxy_cred = proxy.credentials();
         if (!proxy.is_default())
         {
             request->report_exception(http_exception(L"Only a default proxy server is supported"));
@@ -431,8 +437,8 @@ protected:
         // New scope to ensure plain text password is cleared as soon as possible.
         {
             utility::string_t username, proxy_username;
-            const utility::char_t *password = nullptr;
-            const utility::char_t *proxy_password = nullptr;
+            const utility::char_t* password = nullptr;
+            const utility::char_t* proxy_password = nullptr;
             ::web::details::plaintext_string password_plaintext, proxy_password_plaintext;
 
             if (client_cred.is_set())
@@ -448,14 +454,13 @@ protected:
                 proxy_password = proxy_password_plaintext->c_str();
             }
 
-            hr = winrt_context->m_hRequest->Open(
-                msg.method().c_str(),
-                encoded_resource.c_str(),
-                Make<HttpRequestCallback>(winrt_context).Get(),
-                username.c_str(),
-                password,
-                proxy_username.c_str(),
-                proxy_password);
+            hr = winrt_context->m_hRequest->Open(msg.method().c_str(),
+                                                 encoded_resource.c_str(),
+                                                 Make<HttpRequestCallback>(winrt_context).Get(),
+                                                 username.c_str(),
+                                                 password,
+                                                 proxy_username.c_str(),
+                                                 proxy_password);
         }
         if (FAILED(hr))
         {
@@ -493,7 +498,7 @@ protected:
 #endif
 
         // Add headers.
-        for (const auto &hdr : msg.headers())
+        for (const auto& hdr : msg.headers())
         {
             winrt_context->m_hRequest->SetRequestHeader(hdr.first.c_str(), hdr.second.c_str());
         }
@@ -523,38 +528,41 @@ protected:
         }
         else
         {
-            if ( msg.method() == http::methods::GET || msg.method() == http::methods::HEAD )
+            if (msg.method() == http::methods::GET || msg.method() == http::methods::HEAD)
             {
                 request->report_exception(http_exception(get_with_body_err_msg));
                 return;
             }
 
-            hr = winrt_context->m_hRequest->Send(Make<IRequestStream>(winrt_context, content_length).Get(), content_length);
+            hr = winrt_context->m_hRequest->Send(Make<IRequestStream>(winrt_context, content_length).Get(),
+                                                 content_length);
         }
 
-        if ( FAILED(hr) )
+        if (FAILED(hr))
         {
             request->report_error(hr, L"Failure to send HTTP request");
             return;
         }
 
         // Register for notification on cancellation to abort this request.
-        if(msg._cancellation_token() != pplx::cancellation_token::none())
+        if (msg._cancellation_token() != pplx::cancellation_token::none())
         {
             auto requestHandle = winrt_context->m_hRequest;
 
             // cancellation callback is unregistered when request is completed.
-            winrt_context->m_cancellationRegistration = msg._cancellation_token().register_callback([requestHandle]()
-            {
-                requestHandle->Abort();
-            });
+            winrt_context->m_cancellationRegistration =
+                msg._cancellation_token().register_callback([requestHandle]() { requestHandle->Abort(); });
         }
     }
 };
 
-std::shared_ptr<_http_client_communicator> create_platform_final_pipeline_stage(uri&& base_uri, http_client_config&& client_config)
+std::shared_ptr<_http_client_communicator> create_platform_final_pipeline_stage(uri&& base_uri,
+                                                                                http_client_config&& client_config)
 {
     return std::make_shared<details::winrt_client>(std::move(base_uri), std::move(client_config));
 }
 
-}}}}
+} // namespace details
+} // namespace client
+} // namespace http
+} // namespace web
