@@ -287,7 +287,11 @@ static const utility::char_t* stream_was_set_explicitly =
 static const utility::char_t* unsupported_charset =
     _XPLATSTR("Charset must be iso-8859-1, utf-8, utf-16, utf-16le, or utf-16be to be extracted.");
 
-http_msg_base::http_msg_base() : m_headers(), m_default_outstream(false) {}
+http_msg_base::http_msg_base()
+    : m_http_version(http::http_version{ 0, 0 })
+    , m_headers()
+    , m_default_outstream(false)
+{}
 
 void http_msg_base::_prepare_to_receive_data()
 {
@@ -423,14 +427,25 @@ void http_msg_base::_complete(utility::size64_t body_size, const std::exception_
 {
     const auto& completionEvent = _get_data_available();
     auto closeTask = pplx::task_from_result();
+    if (m_default_outstream)
+    {
+        // if the outstream is one we created by default on the customer's behalf, try to close it
+        auto& out = outstream();
+        if (out.is_valid())
+        {
+            if (exceptionPtr == std::exception_ptr())
+            {
+                closeTask = out.close();
+            }
+            else
+            {
+                closeTask = out.close(exceptionPtr);
+            }
+        }
+    }
 
     if (exceptionPtr == std::exception_ptr())
     {
-        if (m_default_outstream)
-        {
-            closeTask = outstream().close();
-        }
-
         inline_continuation(closeTask, [completionEvent, body_size](pplx::task<void> t) {
             try
             {
@@ -455,11 +470,6 @@ void http_msg_base::_complete(utility::size64_t body_size, const std::exception_
     }
     else
     {
-        if (outstream().is_valid())
-        {
-            closeTask = outstream().close(exceptionPtr);
-        }
-
         inline_continuation(closeTask, [completionEvent, exceptionPtr](pplx::task<void> t) {
             // If closing stream throws an exception ignore since we already have an error.
             try
@@ -1122,7 +1132,6 @@ details::_http_request::_http_request(http::method mtd)
     , m_initiated_response(0)
     , m_server_context()
     , m_cancellationToken(pplx::cancellation_token::none())
-    , m_http_version(http::http_version {0, 0})
 {
     if (m_method.empty())
     {
@@ -1134,7 +1143,6 @@ details::_http_request::_http_request(std::unique_ptr<http::details::_http_serve
     : m_initiated_response(0)
     , m_server_context(std::move(server_context))
     , m_cancellationToken(pplx::cancellation_token::none())
-    , m_http_version(http::http_version {0, 0})
 {
 }
 
